aboutsummaryrefslogtreecommitdiffstats
path: root/resources/jquery.ui/jquery.ui.datepicker.js
diff options
context:
space:
mode:
authorKrinkle <ttijhof@wikimedia.org>2012-08-29 20:56:43 +0000
committerGerrit Code Review <gerrit@wikimedia.org>2012-08-29 20:56:43 +0000
commitc24daca2ff833adcd0a496b63d91302606b7ffe5 (patch)
treeb5a7fe4117f016df3ab13c7b4d9ffe105fc79976 /resources/jquery.ui/jquery.ui.datepicker.js
parent731219d5d1c82eb199eb9808948740555d2ebe14 (diff)
downloadmediawikicore-c24daca2ff833adcd0a496b63d91302606b7ffe5.tar.gz
mediawikicore-c24daca2ff833adcd0a496b63d91302606b7ffe5.zip
Revert "Revert "Update jQuery UI to 1.8.23""
Problems solved. This reverts commit 731219d5d1c82eb199eb9808948740555d2ebe14
Diffstat (limited to 'resources/jquery.ui/jquery.ui.datepicker.js')
-rw-r--r--resources/jquery.ui/jquery.ui.datepicker.js8
1 files changed, 4 insertions, 4 deletions
diff --git a/resources/jquery.ui/jquery.ui.datepicker.js b/resources/jquery.ui/jquery.ui.datepicker.js
index 58d3ff297a2e..7ea5b079193e 100644
--- a/resources/jquery.ui/jquery.ui.datepicker.js
+++ b/resources/jquery.ui/jquery.ui.datepicker.js
@@ -1,5 +1,5 @@
/*!
* jQuery UI Datepicker 1.8.22
*
* Copyright 2012, AUTHORS.txt (http://jqueryui.com/about)
* Dual licensed under the MIT or GPL Version 2 licenses.
@@ -12,7 +12,7 @@
*/
(function( $, undefined ) {
-$.extend($.ui, { datepicker: { version: "1.8.22" } });
+$.extend($.ui, { datepicker: { version: "1.8.23" } });
var PROP_NAME = 'datepicker';
var dpuuid = new Date().getTime();
@@ -1408,7 +1408,7 @@ $.extend(Datepicker.prototype, {
*/
_attachHandlers: function(inst) {
var stepMonths = this._get(inst, 'stepMonths');
- var id = '#' + inst.id;
+ var id = '#' + inst.id.replace( /\\\\/g, "\\" );
inst.dpDiv.find('[data-handler]').map(function () {
var handler = {
prev: function () {
@@ -1845,7 +1845,7 @@ $.fn.datepicker = function(options){
$.datepicker = new Datepicker(); // singleton instance
$.datepicker.initialized = false;
$.datepicker.uuid = new Date().getTime();
-$.datepicker.version = "1.8.22";
+$.datepicker.version = "1.8.23";
// Workaround for #4055
// Add another global to avoid noConflict issues with inline event handlers
@@ -1,5 +1,5 @@
/*!
- * jQuery UI Datepicker 1.8.22
+ * jQuery UI Datepicker 1.8.23
*
* Copyright 2012, AUTHORS.txt (http://jqueryui.com/about)